@@ -2,6 +2,7 @@ from typing import List, Type
 
 import pandas as pd
 import pytest
+from sklearn.base import is_regressor
 from sklearn.multioutput import MultiOutputRegressor, RegressorChain
 
 import sklearndf.regression
@@ -37,14 +38,6 @@ DEFAULT_REGRESSOR_PARAMETERS = {
 }
 
 
-@pytest.mark.parametrize(argnames="sklearndf_cls", argvalues=REGRESSORS_TO_TEST)
-def test_wrapped_constructor(sklearndf_cls: Type) -> None:
-    """ Test standard constructor of wrapped sklearn regressors """
-    _: RegressorDF = sklearndf_cls(
-        **DEFAULT_REGRESSOR_PARAMETERS.get(sklearndf_cls.__name__, {})
-    )
-
-
 @pytest.mark.parametrize(argnames="sklearndf_cls", argvalues=REGRESSORS_TO_TEST)
 def test_wrapped_fit_predict(
     sklearndf_cls: Type,
@@ -57,6 +50,8 @@ def test_wrapped_fit_predict(
         **DEFAULT_REGRESSOR_PARAMETERS.get(sklearndf_cls.__name__, {})
     )
 
+    assert is_regressor(regressor)
+
     check_expected_not_fitted_error(estimator=regressor)
 
     if (
